api.sampledb.v1.submission.test_helpers.submission_search package — Argus-Toolbelt 1.0 documentation

# api.sampledb.v1.submission.test_helpers.submission_search package

## Submodules

## api.sampledb.v1.submission.test_helpers.submission_search.get_submission_by_id module

`api.sampledb.v1.submission.test_helpers.submission_search.get_submission_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/submission/w+, respond with HTTP 403

`api.sampledb.v1.submission.test_helpers.submission_search.get_submission_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/submission/w+, respond with HTTP 404

`api.sampledb.v1.submission.test_helpers.submission_search.get_submission_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/submission/w+, respond with HTTP 200

`api.sampledb.v1.submission.test_helpers.submission_search.get_submission_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/submission/w+, respond with HTTP 401

## api.sampledb.v1.submission.test_helpers.submission_search.search_meta_submissions module

`api.sampledb.v1.submission.test_helpers.submission_search.search_meta_submissions.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/submission/search, respond with HTTP 403

`api.sampledb.v1.submission.test_helpers.submission_search.search_meta_submissions.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/submission/search, respond with HTTP 404

`api.sampledb.v1.submission.test_helpers.submission_search.search_meta_submissions.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/submission/search, respond with HTTP 200

`api.sampledb.v1.submission.test_helpers.submission_search.search_meta_submissions.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/submission/search, respond with HTTP 401

## Module contents